==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/statistiques/lang/statistiques_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/statistiques?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'archiver' => 'Arquivà',
	'archiver_concatener_explications' => 'Aquela ouperacioun va councatenà li estatìstica de visita dei article :',
	'archiver_concatener_ignorer' => 'Li visita de mens de @nb@ an noun soun toucadi.',
	'archiver_concatener_par_an' => 'Li visita de mai de @nb@ an seràn coucaternadi, per cada article, en lou premié jou de cada anada.',
	'archiver_concatener_par_mois' => 'Li visita de mai de @nb@ an seràn councatenadi, per cada article, en lou premié jou de cada mès.',
	'archiver_conseil_sauvegarde' => 'Es counseiat de faire una sauvagarda preliminari de la basa de dounada.',
	'archiver_description' => 'Aquela pàgina fournisse lu óutis da netegià o arquivà li estatìstica dóu sit.',
	'archiver_et_nettoyer' => 'Arquivà e netegià',
	'archiver_nettoyer' => 'Netegià',
	'archiver_nettoyer_explications' => 'Leva li ligna de referençaire o de visita dai article que noun esiston (o esiston pu) en la basa de dounada.',
	'archiver_nettoyer_referers_articles' => 'Netegià li referençaire dai article',
	'archiver_nettoyer_visites_articles' => 'Netegià li visita d’article',
	'archiver_nombre_lignes' => 'Noumbre de ligna',
	'archiver_operation_longue' => 'Aquela ouperacioun pòu estre fouòrça lònga, subretout dóu tems de la premièra esecucioun.',
	'archiver_operations_irreversibles' => 'Aqueli ouperacioun soun ireversìbli !',

	// B
	'bouton_effacer_referers' => 'Escassà basta lu estac entrant',
	'bouton_effacer_statistiques' => 'Escassà touti li estatìstica',

	// C
	'csv' => 'csv',

	// I
	'icone_evolution_visites' => 'Evoulucioun dei visita<br />@visites@ visita',
	'icone_repartition_actuelle' => 'Afichà la reparticioun atuala',
	'icone_repartition_visites' => 'Reparticioun dei visita',
	'icone_statistiques_visites' => 'Estatìstica',
	'info_affichier_visites_articles_plus_visites' => 'Afichà li visita per <b>lu article lu mai visitat despì lou principi :</b>',
	'info_comment_lire_tableau' => 'Couma lire aqueu tabléu',
	'info_forum_statistiques' => 'Estatìstica dei visita',
	'info_graphiques' => 'Gràficou',
	'info_popularite_2' => 'poupularità dóu sit :',
	'info_popularite_3' => 'poupularità : @popularite@ ; visita : @visites@',
	'info_popularite_5' => 'poupularità :',
	'info_previsions' => 'previsioun :',
	'info_question_vignettes_referer' => 'Coura counsultàs li estatìstica, poudès visualisà lu aperçut dei sit d’orìgine dei visita',
	'info_question_vignettes_referer_oui' => 'Afichà li catura dei sit d’orìgine dei visita',
	'info_tableaux' => 'Tabléu',
	'info_visites' => 'visita :',
	'info_visites_plus_populaires' => 'Afichà li visita per <b>lu article lu mai poupulari</b> e per <b>lu darrié article publicat :</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Gerà li estatistica dei visita',

	// O
	'onglet_origine_visites' => 'Orìgine dei visita',
	'onglet_repartition_debut' => 'despì lou principi',
	'onglet_repartition_lang' => 'Reparticioun per lenga',

	// R
	'resume' => 'Coumpèndi',

	// T
	'texte_admin_effacer_stats' => 'Aquela coumanda escassa touti li dounada ligadi ai estatìstica de visita dóu sit, embé la poupularità dei article.',
	'texte_admin_effacer_toutes_stats' => 'Lou premié boutoun suprima touti li esttìstica : visita, poupularità dei article e estac entant.',
	'texte_comment_lire_tableau' => 'Lou ran de l’article, en lou classamen per poupularità, es endicat en la marge ; la poupularità de l’article (una estimacioun dóu noumbre de visita quoutidiana que recevrà se lou rìtoumou atual de counsultacioun si mantengue) e lou noumbre de visita reçudi despì lou principi soun afichat en la boufa que pareisse coura la rateta survoula lou titre.',
	'texte_signification' => 'Li barra founçadi rapresenton li intrada cumuladi (toutal dei souta rùbrica), li barra clara lou noumbre de visita per cada rùbrica.',
	'titre_evolution_visite' => 'Evoulucioun dei visita',
	'titre_liens_entrants' => 'Estac intrant',
	'titre_page_statistiques' => 'Estatistica per rùbrica',
	'titre_page_statistiques_visites' => 'Estatistica dei visita',

	// V
	'visites_journalieres' => 'Noumbre de visita per jou',
	'visites_mensuelles' => 'Noumbre de visita per mès'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/statistiques/lang/statistiques_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/statistiques?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'archiver' => 'Arquivà',
	'archiver_concatener_explications' => 'Aquela ouperacioun va councatenà li estatìstica de visita dei article :',
	'archiver_concatener_ignorer' => 'Li visita de mens de @nb@ an noun soun toucadi.',
	'archiver_concatener_par_an' => 'Li visita de mai de @nb@ an seràn coucaternadi, per cada article, en lou premié jou de cada anada.',
	'archiver_concatener_par_mois' => 'Li visita de mai de @nb@ an seràn councatenadi, per cada article, en lou premié jou de cada mès.',
	'archiver_conseil_sauvegarde' => 'Es counseiat de faire una sauvagarda preliminari de la basa de dounada.',
	'archiver_description' => 'Aquela pàgina fournisse lu óutis da netegià o arquivà li estatìstica dóu sit.',
	'archiver_et_nettoyer' => 'Arquivà e netegià',
	'archiver_nettoyer' => 'Netegià',
	'archiver_nettoyer_explications' => 'Leva li ligna de "referençaire" o de "visita" dai article que noun esiston (o esiston pu) en la basa de dounada.',
	'archiver_nettoyer_referers_articles' => 'Netegià referers_articles',
	'archiver_nettoyer_visites_articles' => 'Netegià visites_articles',
	'archiver_nombre_lignes' => 'Noumbre de ligna',
	'archiver_operation_longue' => 'Aquela ouperacioun pòu estre fouòrça lònga, subretout dóu tems de la premièra esecucioun.',
	'archiver_operations_irreversibles' => 'Aqueli ouperacioun soun ireversìbli !',

	// B
	'bouton_effacer_referers' => 'Escassà basta lu estac entrant',
	'bouton_effacer_statistiques' => 'Escassà touti li estatìstica',

	// C
	'csv' => 'csv',

	// I
	'icone_evolution_visites' => 'Evoulucioun dei visita<br />@visites@ visita',
	'icone_repartition_actuelle' => 'Afichà la reparticioun atuala',
	'icone_repartition_visites' => 'Reparticioun dei visita',
	'icone_statistiques_visites' => 'Estatìstica',
	'info_affichier_visites_articles_plus_visites' => 'Afichà li visita per <b>lu article lu mai visitat despì lou principi :</b>',
	'info_comment_lire_tableau' => 'Couma lire aqueu tabléu',
	'info_forum_statistiques' => 'Estatìstica dei visita',
	'info_graphiques' => 'Gràficou',
	'info_popularite_2' => 'poupularità dóu sit :',
	'info_popularite_3' => 'poupularità : @popularite@ ; visita : @visites@',
	'info_popularite_5' => 'poupularità :',
	'info_previsions' => 'previsioun :',
	'info_question_vignettes_referer' => 'Coura counsultàs li estatìstica, poudès visualisà lu aperçut dei sit d’orìgine dei visita',
	'info_question_vignettes_referer_oui' => 'Afichà li catura dei sit d’orìgine dei visita',
	'info_tableaux' => 'Tabléu',
	'info_visites' => 'visita :',
	'info_visites_plus_populaires' => 'Afichà li visita per <b>lu article lu mai poupulari</b> e per <b>lu darrié article publicat :</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Gerà li estatistica dei visita',

	// O
	'onglet_origine_visites' => 'Orìgine dei visita',
	'onglet_repartition_debut' => 'despì lou principi',
	'onglet_repartition_lang' => 'Reparticioun per lenga',

	// R
	'resume' => 'Coumpèndi',

	// T
	'texte_admin_effacer_stats' => 'Aquela coumanda escassa touti li dounada ligadi ai estatìstica de visita dóu sit, embé la poupularità dei article.',
	'texte_admin_effacer_toutes_stats' => 'Lou premié boutoun suprima touti li esttìstica : visita, poupularità dei article e estac entant.',
	'texte_comment_lire_tableau' => 'Lou ran de l’article, en lou classamen per poupularità, es endicat en la marge ; la poupularità de l’article (una estimacioun dóu noumbre de visita quoutidiana que recevrà se lou rìtoumou atual de counsultacioun si mantengue) e lou noumbre de visita reçudi despì lou principi soun afichat en la boufa que pareisse coura la rateta survoula lou titre.',
	'texte_signification' => 'Li barra founçadi rapresenton li intrada cumuladi (toutal dei souta rùbrica), li barra clara lou noumbre de visita per cada rùbrica.',
	'titre_evolution_visite' => 'Evoulucioun dei visita',
	'titre_liens_entrants' => 'Estac intrant',
	'titre_page_statistiques' => 'Estatistica per rùbrica',
	'titre_page_statistiques_visites' => 'Estatistica dei visita',

	// V
	'visites_journalieres' => 'Noumbre de visita per jou',
	'visites_mensuelles' => 'Noumbre de visita per mès'
);

?>
